<div class="flex flex-row items-center max-w-2xl">
    {% for widget in widget.subwidgets %}
        {% include widget.template_name %}

        {% if forloop.first %}
            <div class="px-4 text-base-300">
                -
            </div>
        {% endif %}
    {% endfor %}
</div>
