{% extends 'admin/base.html' %}

{% load i18n %}

{% block title %}{% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block branding %}
    {% include "unfold/helpers/site_branding.html" %}
{% endblock %}

{% block content %}
    <div class="flex flex-col lg:flex-row lg:gap-8">
        <div class="grow">
            {% include "unfold/helpers/app_list_default.html" %}
        </div>

        {% include "unfold/helpers/history.html" %}
    </div>
{% endblock %}
