<div class="flex flex-col gap-2">
    {% include "django/forms/widgets/input.html" %}

    {% if url_valid %}
        <p class="text-xs">
            {{ current_label }} <a href="{{ widget.href }}" class="text-primary-600 dark:text-primary-500">{{ widget.value }}</a>
        </p>
    {% endif %}
</div>
