{% extends "admin/base_site.html" %}
{% load admin_urls i18n static %}

{% block extrastyle %}{{ block.super }}{% endblock %}

{% block bodyclass %}{{ block.super }} {{ opts.app_label }}-{{ opts.model_name }} change-form{% endblock %}

{% block content %}
    <div id="content-main">
        <form{% if form_url %} action="{{ form_url }}"{% endif %} method="post" id="{{ opts.model_name }}_form">{% csrf_token %}{% block form_top %}{% endblock %}
            <input type="text" name="username" value="{{ original.get_username }}" class="hidden">

            {% if is_popup %}
                <input type="hidden" name="{{ is_popup_var }}" value="1">
            {% endif %}

            {% include "unfold/helpers/messages/errornote.html" with errors=form.errors %}

            {% blocktranslate with username=original asvar message %}Enter a new password for the user <strong>{{ username }}</strong>.{% endblocktranslate %}
            {% include "unfold/helpers/messages/info.html" with message=message %}

            <fieldset class="border border-base-200 mb-8 rounded-default pt-3 px-3 shadow-xs dark:border-base-800">

                {% include "unfold/helpers/field.html" with field=form.password1 %}

                {% include "unfold/helpers/field.html" with field=form.password2 %}
            </fieldset>

            <button type="submit" class="bg-primary-600 border border-transparent font-medium px-3 py-2 rounded-default text-sm text-white">
                {% translate 'Change password' %}
            </button>
        </form>
    </div>
{% endblock %}
